@@ -7,6 +7,6 @@ test_that("list_channel_activities runs successfully", {
   google_token <- readRDS("token_file.rds")$google_token
   options(google_token=google_token)
 
-  get_info <- list_channel_activities(channel_id="UCRw8bIz2wMLmfgAgWm903cA")
+  get_info <- list_channel_activities(filter = c(channel_id="UCRw8bIz2wMLmfgAgWm903cA"))
   expect_that(get_info, is_a("list"))
 })
\ No newline at end of file
